fisx: Class Members

fisx

Here is a list of all documented class members with links to the class documentation for each member:

### - s -

- setActiveArea() : fisx::Detector
- setAtomicMass() : fisx::Element
- setAtomicNumber() : fisx::Element
- setAttenuators() : fisx::XRF , fisx::XRFConfig
- setBeam() : fisx::Beam , fisx::XRF , fisx::XRFConfig
- setBeamFilters() : fisx::XRF , fisx::XRFConfig
- setBindingEnergies() : fisx::Element
- setCacheEnabled() : fisx::Element , fisx::Elements
- setCascadeCacheEnabled() : fisx::Element
- setCollimators() : fisx::XRF , fisx::XRFConfig
- setColumn() : fisx::Element
- setComposition() : fisx::Material
- setConfiguration() : fisx::XRF
- setDensity() : fisx::Element
- setDetector() : fisx::XRF , fisx::XRFConfig
- setDiameter() : fisx::Detector
- setDistance() : fisx::Detector
- setElementCascadeCacheEnabled() : fisx::Elements
- setGeometry() : fisx::XRF , fisx::XRFConfig
- setLongName() : fisx::Element
- setMassAttenuationCoefficients() : fisx::Element , fisx::Elements
- setMassAttenuationCoefficientsFile() : fisx::Elements
- setMaterialComposition() : fisx::Elements
- setName() : fisx::Element
- setNonradiativeTransitions() : fisx::Shell
- setPartialPhotoelectricMassAttenuationCoefficients() : fisx::Element
- setRadiativeTransitions() : fisx::Shell
- setReferenceLayer() : fisx::XRF , fisx::XRFConfig
- setRow() : fisx::Element
- setSample() : fisx::XRF , fisx::XRFConfig
- setShellConstants() : fisx::Shell
- setShellConstantsFile() : fisx::Elements
- setShellNonradiativeTransitionsFile() : fisx::Elements
- setShellRadiativeTransitionsFile() : fisx::Elements
- setTotalMassAttenuationCoefficient() : fisx::Element
- setTransmissionTable() : fisx::TransmissionTable
- setUserAttenuators() : fisx::XRF , fisx::XRFConfig
- setUserBeamFilters() : fisx::XRF , fisx::XRFConfig
- Shell() : fisx::Shell
- startsWith() : fisx::SimpleIni
- stringToDouble() : fisx::Elements